@@ -8,17 +8,28 @@ package KinoSearch::Build::CBuilder;
 BEGIN { our @ISA = "ExtUtils::CBuilder"; }
 use Config;
 
+my %cc;
+
 sub new {
-    my $class = shift;
+    my ($class, %args) = @_;
     require ExtUtils::CBuilder;
-    return $class->SUPER::new(@_);
+    my $self = $class->SUPER::new(%args);
+    $cc{"$self"} = $args{'config'}->{'cc'};
+    return $self;
+}
+
+sub get_cc { $cc{"$_[0]"} }
+
+sub DESTROY {
+    my $self = shift;
+    delete $cc{"$self"};
 }
 
 # This method isn't implemented by CBuilder for Windows, so we issue a basic
 # link command that works on at least one system and hope for the best.
 sub link_executable {
     my ( $self, %args ) = @_;
-    if ( $Config{cc} eq 'cl' ) {
+    if ( $self->get_cc eq 'cl' ) {
         my ( $objects, $exe_file ) = @args{qw( objects exe_file )};
         $self->do_system("link /out:$exe_file @$objects");
         return $exe_file;
@@ -47,11 +58,11 @@ sub xs_filepath { catfile( 'lib', "KinoSearch.xs" ) }
 sub autobind_pm_path { catfile( 'lib', 'KinoSearch', 'Autobinding.pm' ); }
 
 sub extra_ccflags {
-    my $self          = shift;
+    my $self = shift;
     my $extra_ccflags = defined $ENV{CFLAGS} ? "$ENV{CFLAGS} " : "";
     my $gcc_version 
         = $ENV{REAL_GCC_VERSION}
-        || $Config{gccversion}
+        || $self->config('gccversion')
         || undef;
     if ( defined $gcc_version ) {
         $gcc_version =~ /^(\d+(\.\d+))/
@@ -74,20 +85,20 @@ sub extra_ccflags {
     }
 
     # Compile as C++ under MSVC.
-    if ( $Config{cc} eq 'cl' ) {
+    if ( $self->config('cc') eq 'cl' ) {
         $extra_ccflags .= '/TP ';
     }
-    
+
     if ( defined $gcc_version ) {
         # Tell GCC explicitly to run with C99 compatability.
-        if ($extra_ccflags !~ m/-std=c99/) {
+        if ( $extra_ccflags !~ m/-std=c99/ ) {
             $extra_ccflags .= "-std=c99 ";
-        }  
-        if ($extra_ccflags !~ m/-D_GNU_SOURCE/) {
+        }
+        if ( $extra_ccflags !~ m/-D_GNU_SOURCE/ ) {
             $extra_ccflags .= "-D_GNU_SOURCE ";
-        } 
+        }
     }
-    
+
     return $extra_ccflags;
 }
 
@@ -129,7 +140,9 @@ sub ACTION_charmonizer {
 
     print "Building $CHARMONIZE_EXE_PATH...\n\n";
 
-    my $cbuilder = KinoSearch::Build::CBuilder->new;
+    my $cbuilder = KinoSearch::Build::CBuilder->new( 
+        config => { cc => $self->config('cc') },
+    );
 
     my @o_files;
     for (@all_source) {
@@ -169,8 +182,8 @@ sub ACTION_charmony {
     $self->add_to_cleanup("_charm*");
 
     # Prepare arguments to charmonize.
-    my $cc        = "$Config{cc}";
-    my $flags     = "$Config{ccflags} " . $self->extra_ccflags;
+    my $cc        = $self->config('cc'); 
+    my $flags     = $self->config('ccflags') . ' ' . $self->extra_ccflags;
     my $verbosity = $ENV{DEBUG_CHARM} ? 2 : 1;
     $flags =~ s/"/\\"/g;
 
@@ -180,8 +193,8 @@ sub ACTION_charmony {
             and die "Failed to write charmony.h";
     }
     else {
-        system("./$CHARMONIZE_EXE_PATH $cc \"$flags\" $verbosity")
-            and die "Failed to write charmony.h";
+        system("./$CHARMONIZE_EXE_PATH \"$cc\" \"$flags\" $verbosity")
+            and die "Failed to write charmony.h: $!";
     }
 }
 
@@ -216,12 +229,12 @@ sub _compile_clownfish {
     }
 
     my $binding = Clownfish::Binding::Perl->new(
-        parcel      => 'KinoSearch',
-        hierarchy   => $hierarchy,
-        lib_dir     => 'lib',
-        boot_class  => 'KinoSearch',
-        header      => $self->autogen_header,
-        footer      => $self->copyfoot,
+        parcel     => 'KinoSearch',
+        hierarchy  => $hierarchy,
+        lib_dir    => 'lib',
+        boot_class => 'KinoSearch',
+        header     => $self->autogen_header,
+        footer     => $self->copyfoot,
     );
 
     return ( $hierarchy, $binding, \@pm_filepaths_with_xs );
@@ -341,7 +354,7 @@ sub ACTION_suppressions {
     my $LOCAL_SUPP = 'local.supp';
     return
         if $self->up_to_date( '../devel/bin/valgrind_triggers.pl',
-                $LOCAL_SUPP );
+        $LOCAL_SUPP );
 
     # Generate suppressions.
     print "Writing $LOCAL_SUPP...\n";
@@ -381,7 +394,7 @@ sub _valgrind_base_command {
 sub ACTION_test_valgrind {
     my $self = shift;
     die "Must be run under a perl that was compiled with -DDEBUGGING"
-        unless $Config{ccflags} =~ /-D?DEBUGGING\b/;
+        unless $self->config('ccflags') =~ /-D?DEBUGGING\b/;
     $self->dispatch('code');
     $self->dispatch('suppressions');
 
@@ -443,7 +456,9 @@ sub ACTION_compile_custom_xs {
 
     require ExtUtils::ParseXS;
 
-    my $cbuilder = KinoSearch::Build::CBuilder->new;
+    my $cbuilder = KinoSearch::Build::CBuilder->new(
+        config => { cc => $self->config('cc') },
+    );
     my $archdir = catdir( $self->blib, 'arch', 'auto', 'KinoSearch', );
     mkpath( $archdir, 0, 0777 ) unless -d $archdir;
     my @include_dirs = (
@@ -483,7 +498,7 @@ sub ACTION_compile_custom_xs {
     }
 
     # .c => .o
-    my $version             = $self->dist_version;
+    my $version = $self->dist_version;
     my $perl_binding_o_file = catfile( 'lib', "KinoSearch$Config{_o}" );
     unshift @objects, $perl_binding_o_file;
     $self->add_to_cleanup($perl_binding_o_file);
@@ -575,7 +590,7 @@ END_AUTOGEN
 }
 
 sub copyfoot {
-        return <<END_COPYFOOT;
+    return <<END_COPYFOOT;
 /* Copyright 2005-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
@@ -639,12 +654,13 @@ sub _gen_pause_exclusion_list {
     }
 
     # Exclude redacted modules.
-    require "buildlib/KinoSearch/Redacted.pm";
-    my @redacted = map {
-        my @parts = split( /\W+/, $_ );
-        catfile( 'lib', @parts ) . '.pm'
-    } KinoSearch::Redacted->redacted, KinoSearch::Redacted->hidden;
-    push @excluded_files, @redacted;
+    if ( eval { require "buildlib/KinoSearch/Redacted.pm" } ) {
+        my @redacted = map {
+            my @parts = split( /\W+/, $_ );
+            catfile( 'lib', @parts ) . '.pm'
+        } KinoSearch::Redacted->redacted, KinoSearch::Redacted->hidden;
+        push @excluded_files, @redacted;
+    }
 
     my %uniquifier;
     @excluded_files = sort grep { !$uniquifier{$_}++ } @excluded_files;
@@ -655,11 +671,10 @@ sub _gen_pause_exclusion_list {
 
 __END__
 
-__POD__
-
-=head1 COPYRIGHT AND LICENSE
+__COPYRIGHT__
 
 Copyright 2005-2010 Marvin Humphrey
 
-=cut
+This program is free software; you can redistribute it and/or modify
+under the same terms as Perl itself.
 
