@@ -23,21 +23,21 @@ TestFuncMacro_run(TestBatch *batch)
 {
 
 #ifdef HAS_FUNC_MACRO
-    TEST_STR_EQ(batch, FUNC_MACRO, "chaz_TestFuncMacro_run", 
+    ASSERT_STR_EQ(batch, FUNC_MACRO, "chaz_TestFuncMacro_run", 
         "FUNC_MACRO");
 #else
     SKIP(batch, "no FUNC_MACRO");
 #endif
 
 #ifdef HAS_ISO_FUNC_MACRO
-    TEST_STR_EQ(batch, __func__, "chaz_TestFuncMacro_run",
+    ASSERT_STR_EQ(batch, __func__, "chaz_TestFuncMacro_run",
         "HAS_ISO_FUNC_MACRO");
 #else
     SKIP(batch, "no ISO_FUNC_MACRO");
 #endif
 
 #ifdef HAS_GNUC_FUNC_MACRO
-    TEST_STR_EQ(batch, __FUNCTION__, "chaz_TestFuncMacro_run", 
+    ASSERT_STR_EQ(batch, __FUNCTION__, "chaz_TestFuncMacro_run", 
         "HAS_GNUC_FUNC_MACRO");
 #else
     SKIP(batch, "no GNUC_FUNC_MACRO");
