@@ -6,8 +6,8 @@
 #include "KinoSearch/Index/IndexManager.h"
 #include "KinoSearch/Index/PolyReader.h"
 #include "KinoSearch/Index/Snapshot.h"
-#include "KinoSearch/FieldType.h"
-#include "KinoSearch/Schema.h"
+#include "KinoSearch/Plan/FieldType.h"
+#include "KinoSearch/Plan/Schema.h"
 #include "KinoSearch/Search/Matcher.h"
 #include "KinoSearch/Store/Folder.h"
 #include "KinoSearch/Store/Lock.h"
