@@ -4,9 +4,9 @@
 #include "KinoSearch/Index/Lexicon.h"
 
 Lexicon*
-Lex_init(Lexicon *self)
+Lex_init(Lexicon *self, const CharBuf *field)
 {
-    self->field = NULL;
+    self->field = CB_Clone(field);
     ABSTRACT_CLASS_CHECK(self, LEXICON);
     return self;
 }
@@ -14,6 +14,13 @@ Lex_init(Lexicon *self)
 CharBuf*
 Lex_get_field(Lexicon *self) { return self->field; }
 
+void
+Lex_destroy(Lexicon *self)
+{
+    DECREF(self->field);
+    SUPER_DESTROY(self, LEXICON);
+}
+
 /* Copyright 2006-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
