@@ -1,3 +1,5 @@
+#include <ctype.h>
+
 #define C_KINO_SEGMENT
 #include "KinoSearch/Util/ToolSet.h"
 
@@ -46,6 +48,22 @@ Seg_num_to_name(i64_t number)
     return CB_newf("seg_%s", &base36);
 }
 
+bool_t
+Seg_valid_seg_name(const CharBuf *name)
+{
+    if (CB_Starts_With_Str(name, "seg_", 4)) {
+        size_t size = ZCB_size() + CB_Get_Size(name) + 1;
+        ZombieCharBuf *scratch = ZCB_wrap(alloca(size), name);
+        ZCB_Nip(scratch, 4);
+        uint32_t code_point;
+        while (0 != (code_point = ZCB_Nip_One(scratch))) {
+            if (!isalnum(code_point)) { return false; }
+        }
+        if (ZCB_Get_Size(scratch) == 0) { return true; } // Success!
+    }
+    return false;
+}
+
 void
 Seg_destroy(Segment *self)
 {
@@ -174,8 +192,8 @@ void
 Seg_store_metadata_str(Segment *self, const char *key, size_t key_len, 
                        Obj *value)
 {
-    ZombieCharBuf k = ZCB_make_str((char*)key, key_len);
-    Seg_Store_Metadata(self, (CharBuf*)&k, value);
+    ZombieCharBuf *k = ZCB_WRAP_STR((char*)key, key_len);
+    Seg_Store_Metadata(self, (CharBuf*)k, value);
 }
 
 Obj*
