@@ -52,6 +52,12 @@ Num_compare_to(Num *self, Obj *other)
     return 0;
 }
 
+size_t
+Num_ram_usage(Num *self)
+{
+    return VTable_Get_Obj_Alloc_Size(self->vtable) + Num_Host_RAM_Usage(self);
+}
+
 /***************************************************************************/
 
 FloatNum*
@@ -127,6 +133,13 @@ Float32_clone(Float32 *self)
     return Float32_new(self->value);
 }
 
+void
+Float32_mimic(Float32 *self, Obj *other)
+{
+    Float32 *evil_twin = (Float32*)CERTIFY(other, FLOAT32);
+    self->value = evil_twin->value;
+}
+
 void
 Float32_serialize(Float32 *self, OutStream *outstream)
 {
@@ -179,6 +192,13 @@ Float64_clone(Float64 *self)
     return Float64_new(self->value);
 }
 
+void
+Float64_mimic(Float64 *self, Obj *other)
+{
+    Float64 *evil_twin = (Float64*)CERTIFY(other, FLOAT64);
+    self->value = evil_twin->value;
+}
+
 i32_t
 Float64_hash_code(Float64 *self)
 {
@@ -238,6 +258,13 @@ Int32_clone(Integer32 *self)
     return Int32_new(self->value);
 }
 
+void
+Int32_mimic(Integer32 *self, Obj *other)
+{
+    Integer32 *evil_twin = (Integer32*)CERTIFY(other, INTEGER32);
+    self->value = evil_twin->value;
+}
+
 i32_t
 Int32_hash_code(Integer32 *self)
 {
@@ -296,6 +323,13 @@ Int64_clone(Integer64 *self)
     return Int64_new(self->value);
 }
 
+void
+Int64_mimic(Integer64 *self, Obj *other)
+{
+    Integer64 *evil_twin = (Integer64*)CERTIFY(other, INTEGER64);
+    self->value = evil_twin->value;
+}
+
 i32_t
 Int64_hash_code(Integer64 *self)
 {
