@@ -5,18 +5,19 @@
 
 #include "KinoSearch/Plan/Schema.h"
 #include "KinoSearch/Analysis/Analyzer.h"
-#include "KinoSearch/Index/Similarity.h"
 #include "KinoSearch/Plan/FieldType.h"
 #include "KinoSearch/Plan/BlobType.h"
 #include "KinoSearch/Plan/NumericType.h"
 #include "KinoSearch/Plan/StringType.h"
 #include "KinoSearch/Plan/FullTextType.h"
+#include "KinoSearch/Object/Obj.h"
 #include "KinoSearch/Plan/Architecture.h"
+#include "KinoSearch/Search/Similarity.h"
 #include "KinoSearch/Store/Folder.h"
 #include "KinoSearch/Util/Json.h"
 
-// Scan the array to see if an object testing as Equal is present.  If not,
-// push the elem onto the end of the array.
+/* Scan the array to see if an object testing as Equal is present.  If not,
+ * push the elem onto the end of the array. */
 static void
 S_add_unique(VArray *array, Obj *elem);
 
@@ -29,24 +30,17 @@ S_add_blob_field(Schema *self, const CharBuf *field, FieldType *type);
 static void
 S_add_numeric_field(Schema *self, const CharBuf *field, FieldType *type);
 
-Schema*
-Schema_new()
-{
-    Schema *self = (Schema*)VTable_Make_Obj(SCHEMA);
-    return Schema_init(self);
-}
-
 Schema*
 Schema_init(Schema *self)
 {
-    // Init.
+    /* Init. */
     self->analyzers      = Hash_new(0);
     self->types          = Hash_new(0);
     self->sims           = Hash_new(0);
     self->uniq_analyzers = VA_new(2);
     VA_Resize(self->uniq_analyzers, 1);
 
-    // Assign.
+    /* Assign. */
     self->arch = Schema_Architecture(self);
     self->sim  = Arch_Make_Similarity(self->arch);
 
@@ -74,9 +68,7 @@ S_add_unique(VArray *array, Obj *elem)
         Obj *candidate = VA_Fetch(array, i);
         if (!candidate) { continue; }
         if (elem == candidate) { return; }
-        if (Obj_Get_VTable(elem) == Obj_Get_VTable(candidate)) {
-            if (Obj_Equals(elem, candidate)) { return; }
-        }
+        if (Obj_Equals(elem, candidate)) { return; }
     }
     VA_Push(array, INCREF(elem));
 }
@@ -105,7 +97,7 @@ Schema_spec_field(Schema *self, const CharBuf *field, FieldType *type)
 {
     FieldType *existing  = Schema_Fetch_Type(self, field);
 
-    // If the field already has an association, verify pairing and return.
+    /* If the field already has an association, verify pairing and return. */
     if (existing) {
         if (FType_Equals(type, (Obj*)existing)) { return; }
         else { THROW(ERR, "'%o' assigned conflicting FieldType", field); }
@@ -135,12 +127,12 @@ S_add_text_field(Schema *self, const CharBuf *field, FieldType *type)
     Similarity   *sim       = FullTextType_Make_Similarity(fttype);
     Analyzer     *analyzer  = FullTextType_Get_Analyzer(fttype);
 
-    // Cache helpers.
+    /* Cache helpers. */
     Hash_Store(self->sims, (Obj*)field, (Obj*)sim);
     Hash_Store(self->analyzers, (Obj*)field, INCREF(analyzer));
     S_add_unique(self->uniq_analyzers, (Obj*)analyzer);
 
-    // Store FieldType.
+    /* Store FieldType. */
     Hash_Store(self->types, (Obj*)field, INCREF(type));
 }
 
@@ -150,10 +142,10 @@ S_add_string_field(Schema *self, const CharBuf *field, FieldType *type)
     StringType *string_type = (StringType*)CERTIFY(type, STRINGTYPE);
     Similarity *sim         = StringType_Make_Similarity(string_type);
 
-    // Cache helpers.
+    /* Cache helpers. */
     Hash_Store(self->sims, (Obj*)field, (Obj*)sim);
 
-    // Store FieldType.
+    /* Store FieldType. */
     Hash_Store(self->types, (Obj*)field, INCREF(type));
 }
 
@@ -222,10 +214,8 @@ S_find_in_array(VArray *array, Obj *obj)
             return i;
         }
         else if (obj != NULL && candidate != NULL) {
-            if (Obj_Get_VTable(obj) == Obj_Get_VTable(candidate)) {
-                if (Obj_Equals(obj, candidate)) {
-                    return i;
-                }
+            if (Obj_Equals(obj, candidate)) {
+                return i;
             }
         }
     }
@@ -233,25 +223,6 @@ S_find_in_array(VArray *array, Obj *obj)
     UNREACHABLE_RETURN(uint32_t);
 }
 
-static VTable *old_full_text_type_vtable = NULL;
-static VTable *old_string_type_vtable = NULL;
-static VTable *old_blob_type_vtable = NULL;
-
-// 
-static void
-S_lazy_init_old_type_vtables(void) 
-{
-    if (old_full_text_type_vtable) { return; }
-    CharBuf *klass = CB_new(40);
-    CB_setf(klass, "KinoSearch::FieldType::FullTextType");
-    old_full_text_type_vtable = VTable_singleton(klass, FULLTEXTTYPE);
-    CB_setf(klass, "KinoSearch::FieldType::StringType");
-    old_string_type_vtable = VTable_singleton(klass, STRINGTYPE);
-    CB_setf(klass, "KinoSearch::FieldType::BlobType");
-    old_blob_type_vtable = VTable_singleton(klass, BLOBTYPE);
-    DECREF(klass);
-}
-
 Hash*
 Schema_dump(Schema *self)
 {
@@ -260,44 +231,38 @@ Schema_dump(Schema *self)
     CharBuf *field;
     FieldType *type;
 
-    S_lazy_init_old_type_vtables();
-
-    // Record class name, store dumps of unique Analyzers.
+    /* Record class name, store dumps of unique Analyzers. */
     Hash_Store_Str(dump, "_class", 6, 
         (Obj*)CB_Clone(Schema_Get_Class_Name(self)));
     Hash_Store_Str(dump, "analyzers", 9, (Obj*)VA_Dump(self->uniq_analyzers));
 
-    // Dump FieldTypes.
+    /* Dump FieldTypes. */
     Hash_Store_Str(dump, "fields", 6, (Obj*)type_dumps);
-    Hash_Iterate(self->types);
-    while (Hash_Next(self->types, (Obj**)&field, (Obj**)&type)) {
+    Hash_Iter_Init(self->types);
+    while (Hash_Iter_Next(self->types, (Obj**)&field, (Obj**)&type)) {
         VTable *type_vtable = FType_Get_VTable(type);
 
-        // Dump known types to simplified format.
-        if (   type_vtable == FULLTEXTTYPE
-            || type_vtable == old_full_text_type_vtable
-        ) {
+        /* Dump known types to simplified format. */
+        if (type_vtable == FULLTEXTTYPE) {
             FullTextType *fttype = (FullTextType*)type;
             Hash *type_dump = FullTextType_Dump_For_Schema(fttype);
             Analyzer *analyzer = FullTextType_Get_Analyzer(fttype);
             uint32_t tick 
                 = S_find_in_array(self->uniq_analyzers, (Obj*)analyzer);
 
-            // Store the tick which references a unique analyzer.
+            /* Store the tick which references a unique analyzer. */
             Hash_Store_Str(type_dump, "analyzer", 8, 
                 (Obj*)CB_newf("%u32", tick));
 
             Hash_Store(type_dumps, (Obj*)field, (Obj*)type_dump);
         }
         else if (   type_vtable == STRINGTYPE
-                 || type_vtable == old_string_type_vtable
                  || type_vtable == BLOBTYPE
-                 || type_vtable == old_blob_type_vtable
         ) {
             Hash *type_dump = FType_Dump_For_Schema(type);
             Hash_Store(type_dumps, (Obj*)field, (Obj*)type_dump);
         }
-        // Unknown FieldType type, so punt.
+        /* Unknown FieldType type, so punt. */
         else {
             Hash_Store(type_dumps, (Obj*)field, FType_Dump(type));
         }
@@ -324,18 +289,19 @@ Schema_load(Schema *self, Obj *dump)
     Hash    *type_dump;
     UNUSED_VAR(self);
 
-    // Start with a blank Schema.
+    /* Start with a blank Schema. */
     Schema_init(loaded);
     VA_Grow(loaded->uniq_analyzers, VA_Get_Size(analyzers));
 
-    Hash_Iterate(type_dumps);
-    while (Hash_Next(type_dumps, (Obj**)&field, (Obj**)&type_dump)) {
+    Hash_Iter_Init(type_dumps);
+    while (Hash_Iter_Next(type_dumps, (Obj**)&field, (Obj**)&type_dump)) {
         CharBuf *type_str;
         CERTIFY(type_dump, HASH);
         type_str = (CharBuf*)Hash_Fetch_Str(type_dump, "type", 4);
         if (type_str) {
             if (CB_Equals_Str(type_str, "fulltext", 8)) {
-                // Replace the "analyzer" tick with the real thing.
+                FullTextType *type = (FullTextType*)VTable_Load_Obj(
+                    FULLTEXTTYPE, (Obj*)type_dump);
                 Obj *tick = CERTIFY(
                     Hash_Fetch_Str(type_dump, "analyzer", 8), OBJ);
                 Analyzer *analyzer = (Analyzer*)VA_Fetch(analyzers, 
@@ -343,9 +309,7 @@ Schema_load(Schema *self, Obj *dump)
                 if (!analyzer) { 
                     THROW(ERR, "Can't find analyzer for '%o'", field);
                 }
-                Hash_Store_Str(type_dump, "analyzer", 8, INCREF(analyzer));
-                FullTextType *type = (FullTextType*)VTable_Load_Obj(
-                    FULLTEXTTYPE, (Obj*)type_dump);
+                FullTextType_Set_Analyzer(type, analyzer);
                 Schema_Spec_Field(loaded, field, (FieldType*)type);
                 DECREF(type);
             }
@@ -406,24 +370,16 @@ void
 Schema_eat(Schema *self, Schema *other)
 {
     if (!Schema_Is_A(self, Schema_Get_VTable(other))) {
-        // Special case because of move of KinoSearch::Schema.
-        if (   Schema_Get_VTable(self) == SCHEMA 
-            && CB_Equals_Str(Schema_Get_Class_Name(other),
-                "KinoSearch::Schema", 18)
-        ) {
-            // allow
-        }
-        else {
-            THROW(ERR, "%o not a descendent of %o", 
-                Schema_Get_Class_Name(self), Schema_Get_Class_Name(other));
-        }
+        THROW(ERR, "%o not a descendent of %o", Schema_Get_Class_Name(self),
+            Schema_Get_Class_Name(other));
     }
-
-    CharBuf *field;
-    FieldType *type;
-    Hash_Iterate(other->types);
-    while (Hash_Next(other->types, (Obj**)&field, (Obj**)&type)) {
-        Schema_Spec_Field(self, field, type);
+    else {
+        CharBuf *field;
+        FieldType *type;
+        Hash_Iter_Init(other->types);
+        while (Hash_Iter_Next(other->types, (Obj**)&field, (Obj**)&type)) {
+            Schema_Spec_Field(self, field, type);
+        }
     }
 }
 
@@ -433,7 +389,7 @@ Schema_write(Schema *self, Folder *folder, const CharBuf *filename)
     Hash *dump = Schema_Dump(self);
     ZombieCharBuf *schema_temp = ZCB_WRAP_STR("schema.temp", 11);
     bool_t success;
-    Folder_Delete(folder, (CharBuf*)schema_temp); // Just in case.
+    Folder_Delete(folder, (CharBuf*)schema_temp); /* Just in case. */
     Json_spew_json((Obj*)dump, folder, (CharBuf*)schema_temp);
     success = Folder_Rename(folder, (CharBuf*)schema_temp, filename);
     DECREF(dump);
