@@ -81,6 +81,9 @@ OutStream_destroy(OutStream *self)
     SUPER_DESTROY(self, OUTSTREAM);
 }
 
+CharBuf*
+OutStream_get_path(OutStream *self) { return self->path; }
+
 void 
 OutStream_absorb(OutStream *self, InStream *instream) 
 {
@@ -118,6 +121,15 @@ OutStream_tell(OutStream *self)
     return self->buf_start + self->buf_pos;
 }
 
+int64_t
+OutStream_align(OutStream *self, int64_t modulus)
+{
+    int64_t len = OutStream_Tell(self);
+    int64_t filler_bytes = (modulus - (len % modulus)) % modulus;
+    while (filler_bytes--) { OutStream_Write_U8(self, 0); }
+    return OutStream_Tell(self);
+}
+
 void
 OutStream_flush(OutStream *self) 
 {
