@@ -12,7 +12,7 @@ my $synopsis = <<'END_SYNOPSIS';
     my $manager = KinoSearch::Index::IndexManager->new( host => $hostname );
 
     # Index time:
-    my $indexer = KinoSearch::Indexer->new(
+    my $indexer = KinoSearch::Index::Indexer->new(
         index   => '/path/to/index',
         manager => $manager,
     );
@@ -22,7 +22,7 @@ my $synopsis = <<'END_SYNOPSIS';
         index   => '/path/to/index',
         manager => $manager,
     );
-    my $searcher = KinoSearch::Searcher->new( index => $reader );
+    my $searcher = KinoSearch::Search::IndexSearcher->new( index => $reader );
 END_SYNOPSIS
 
 Clownfish::Binding::Perl::Class->register(
