@@ -7,9 +7,20 @@ __END__
 
 __BINDING__
 
+my $xs_code = <<'END_XS';
+MODULE = KinoSearch    PACKAGE = KinoSearch::Index::SortWriter
+
+void
+set_default_mem_thresh(mem_thresh)
+    size_t mem_thresh;
+PPCODE:
+    kino_SortWriter_set_default_mem_thresh(mem_thresh);
+END_XS
+
 Clownfish::Binding::Perl::Class->register(
     parcel            => "KinoSearch",
     class_name        => "KinoSearch::Index::SortWriter",
+    xs_code           => $xs_code,
     bind_constructors => ["new"],
 );
 
