@@ -1,3 +1,4 @@
+package KinoSearch::Index::TermVector;
 use KinoSearch;
 
 1;
@@ -6,7 +7,7 @@ __END__
 
 __BINDING__
 
-Boilerplater::Binding::Perl::Class->register(
+Clownfish::Binding::Perl::Class->register(
     parcel            => "KinoSearch",
     class_name        => "KinoSearch::Index::TermVector",
     bind_constructors => ["new"],
@@ -21,7 +22,7 @@ Boilerplater::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2005-2009 Marvin Humphrey
+Copyright 2005-2010 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
