@@ -1,3 +1,4 @@
+package KinoSearch::Search::Matcher;
 use KinoSearch;
 
 1;
@@ -15,7 +16,7 @@ my $constructor = <<'END_CONSTRUCTOR_CODE_SAMPLE';
     my $matcher = MyMatcher->SUPER::new;
 END_CONSTRUCTOR_CODE_SAMPLE
 
-Boilerplater::Binding::Perl::Class->register(
+Clownfish::Binding::Perl::Class->register(
     parcel            => "KinoSearch",
     class_name        => "KinoSearch::Search::Matcher",
     bind_methods      => [qw( Next Advance Get_Doc_ID Score Collect )],
@@ -29,7 +30,7 @@ Boilerplater::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2008-2009 Marvin Humphrey
+Copyright 2008-2010 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
